.. highlight:: console

============
Installation
============

Recommended Way
===============

Quite simple::

    $ python -m pip install -U --user mss

Conda Package
-------------

The module is also available from Conda::

    $ conda install -c conda-forge python-mss

From Sources
============

Alternatively, you can get a copy of the module from GitHub::

    $ git clone https://github.com/BoboTiG/python-mss.git
    $ cd python-mss


And then::

    $ python setup.py install --user
